/******************************************************************************
 *
 * FILE: can.h
 *
 * Description:
 *    CAN communication
 *
 * History:
 *    17.11.2017   PN   Initial version
 *    21.02.2018   MF   Rework for SPC570S50, FlexCAN
 *
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 *
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/


#ifndef CAN_H
#define CAN_H

/* ============================================================================
 * CAN EXAMPLE SETTING
 * User ** can ** change it, here in this file
 * ==========================================================================*/

/* External Loop Back mode enable(1) or disable(0)
 * See RM Chapter - External Loop Back mode */
#define CAN_LOOP_BACK_TEST 0

/* ============================================================================
 * CAN, PIN INSTANCES IMPLEMENTATION
 * Only relevant configuration for CAN example
 * ==========================================================================*/
/* CAN Protocol clock*/
#define CAN_PROTOCOL_CLOCK    UC_CAN_CLK  /* The clock is set via BSP during
                                             platform initialization.*/

/* CAN Baud rate */

/* CAN_PROTOCOL_CLOCK /((TSEG1 + TSEG2 + 3) * BRP) = 500 kbit/s (default value
 * for CAN EXAMPLE )*/

/* The default CAN EXAMPLE configuration assume
 * CAN_PROTOCOL_CLOCK/(BRP * CCCU.CCFG.) = 10MHz */

/* Clock Calibration default value /4 */
#define CAN_PROTOCOL_CLK_DIV      (CAN_PROTOCOL_CLOCK/(8))
#define CAN_PROTOCOL_CLK_DIV_NOT_VALID \
             ((CAN_PROTOCOL_CLK_DIV * (8))- CAN_PROTOCOL_CLOCK)
#if ((CAN_PROTOCOL_CLOCK > 10) && !CAN_PROTOCOL_CLK_DIV_NOT_VALID)
#define CAN_CTRL_PRESDIV        (CAN_PROTOCOL_CLK_DIV - 1)
#define CAN_CTRL_PSEG1    7   /* PSEG1 + 1 */
#define CAN_CTRL_PROPSEG  2   /* PROPSEG + 1 */
#define CAN_CTRL_PSEG2    3   /* PSEG2 + 1*/
#define CAN_CTRL_RJW      3   /* */
#define CAN_SYNC_SEG      1   /* default */
#else
#error The protocol frequency is not supported
#endif

/* Shared CAN Message RAM */
#define CAN_SHARED_RAM_ADD_START      0xFFEC0080UL
#define CAN_SHARED_RAM_ADD_END        0xFFEC027FUL

/* CAN port alternate functions */
#define CAN_PIN_SSS_TX 		    0x4  /* Port pin functionality */
#define CAN_PIN_SSS_RX 		    0x3  /* SIUL2_MSCR SSS field */

/* CAN ports */
#define CAN_PIN_PC3		    35
#define CAN_PIN_PC2	        34
#define CAN_PIN_MUX_PC2      0     /* MUX MSCR_MUX[512] NOTE:(512-512 = 0) */

/* CAN Data received ISR Vector */
#define UC_CAN0_ISR_MB4_7 678    /* FLEXCAN0_IFLAG1[4..7] */

/* ============================================================================
 * CAN API INTERFACE
 * ==========================================================================*/

void can_Init(void);
void can_SendData(void);

/* ============================================================================
 * CAN TYPES
 * ==========================================================================*/
typedef struct
{
    uint8_t     IDE;
    uint8_t     LENGTH;
    uint16_t    TIME_STAMP;
    uint32_t    ID;
    uint8_t     Data[8];
}
CAN_MESSAGE_OBJECT_t;

/* ============================================================================
 * CAN EXTERN
 * ==========================================================================*/

extern CAN_MESSAGE_OBJECT_t g_can_TxData;
extern CAN_MESSAGE_OBJECT_t g_can_RxData;

/* ============================================================================
 * CAN CONFIGURATION
 * Example setting
 * ==========================================================================*/

/* ============================================================================
 * CAN CONFIGURATION CHECKS
 * ==========================================================================*/

#endif /* CAN_H */
