/******************************************************************************
 * FILE
 *    uc_spc570s50_spec.h
 *
 * UC ARCHITECTURE:
 *    PowerPC
 *
 * UC FAMILY:
 *    SPC57
 *
 * DESCRIPTION
 *    Configuration and description of uC derivative.
 *    Parameters are taken from uC Datasheet and Reference manual.
 *
 * FILE HISTORY:
 *    V1.0    23.09.2017     RO
 *       > Initial version
 *    V2.0    25.01.2018     RO
 *       > file header update
 *    V3.0    30.01.2018     MF
 *       > file update for SPC572L64
 *    V3.1    02.02.2018     MF
 *       > reused for SPC570S50
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/

#ifndef _UC_SPC570S50_SPEC_H_
#define _UC_SPC570S50_SPEC_H_


/* Signal that uC derivative description exists */
#define UC_SPC57XX_FOUND          1

/* Include vendor provided uC derivative register header file */
#include "ST/SPC570S_4.2.1_RMrev6.h"

/* Get uC configurable parameters */
#include "uc_spc570s50_cfg.h"

/* ============================================================================
 * uC MODULE INSTANCES IMPLEMENTATION
 * Only relevant modules for BSP support package
 * ==========================================================================*/

/* Mode Entry module */
#define UC_MODULE_ME              1

/* Interrupt module */
#define UC_MODULE_INTC            1

/* PLL modules */
#define UC_MODULE_PLL0            1
#define UC_MODULE_PLL1            1

/* Platform FLASH controllers */
#define UC_MODULE_PFLASH0         1
#define UC_MODULE_PFLASH1         0

/* Platform SRAM controllers */
#define UC_MODULE_PRAM0           1
#define UC_MODULE_PRAM1           0
#define UC_MODULE_PRAM2           0
#define UC_MODULE_PRAM3           0

/* Watchdog modules */
#define UC_MODULE_SWT0            1
#define UC_MODULE_SWT1            0
#define UC_MODULE_SWT2            0
#define UC_MODULE_SWT3            0

/* SIUL IO interface */
#define UC_MODULE_SIUL            1

/* PIT0 Timer module */
#define UC_MODULE_PIT0            1

/* SYSCLK Outputs */
#define UC_MODULE_SYSCLK0         1
#define UC_MODULE_SYSCLK1         0

/* CLOCK Generation module */
#define UC_MODULE_CGM             1

/* SC DC Dividers */
#define UC_MODULE_CGM_SC          0
#define UC_MODULE_CGM_SC_DC0      1  /* CORE0_CLK, XBAR_CLK */
#define UC_MODULE_CGM_SC_DC1      1  /* PBRIDGEA_CLK */
#define UC_MODULE_CGM_SC_DC2      1  /* SYSCLK Output */
#define UC_MODULE_CGM_SC_DC3      0  
#define UC_MODULE_CGM_SC_DC4      0  
#define UC_MODULE_CGM_SC_DC5      0  

/* AC0 CLOCK Bridge */
#define UC_MODULE_CGM_AC0         1
#define UC_MODULE_CGM_AC0_DC0     1  /* PIT_CLK */
#define UC_MODULE_CGM_AC0_DC1     1  /* SARADC_CLK */
#define UC_MODULE_CGM_AC0_DC2     1  /* CTU_CLK */
#define UC_MODULE_CGM_AC0_DC3     1  /* DSPI_CLK */
#define UC_MODULE_CGM_AC0_DC4     1  /* LIN_CLK */
#define UC_MODULE_CGM_AC0_DC5     1  /* ETIMER_CLK */

/* AC1 CLOCK Bridge */
#define UC_MODULE_CGM_AC1         1
#define UC_MODULE_CGM_AC1_DC0     1  /* CAN_CLK */
#define UC_MODULE_CGM_AC1_DC1     0
#define UC_MODULE_CGM_AC1_DC2     0
#define UC_MODULE_CGM_AC1_DC3     0
#define UC_MODULE_CGM_AC1_DC4     0
#define UC_MODULE_CGM_AC1_DC5     0

/* AC2 CLOCK Bridge */
#define UC_MODULE_CGM_AC2         1  /* PLL0 Clock Selection */
#define UC_MODULE_CGM_AC2_DC0     0
#define UC_MODULE_CGM_AC2_DC1     0
#define UC_MODULE_CGM_AC2_DC2     0
#define UC_MODULE_CGM_AC2_DC3     0
#define UC_MODULE_CGM_AC2_DC4     0
#define UC_MODULE_CGM_AC2_DC5     0

/* AC3 CLOCK Bridge */
#define UC_MODULE_CGM_AC3         1  /* PLL1 Clock Selection */
#define UC_MODULE_CGM_AC3_DC0     0
#define UC_MODULE_CGM_AC3_DC1     0
#define UC_MODULE_CGM_AC3_DC2     0
#define UC_MODULE_CGM_AC3_DC3     0
#define UC_MODULE_CGM_AC3_DC4     0
#define UC_MODULE_CGM_AC3_DC5     0

/* AC4 CLOCK Bridge */
#define UC_MODULE_CGM_AC4         0
#define UC_MODULE_CGM_AC4_DC0     0
#define UC_MODULE_CGM_AC4_DC1     0
#define UC_MODULE_CGM_AC4_DC2     0
#define UC_MODULE_CGM_AC4_DC3     0
#define UC_MODULE_CGM_AC4_DC4     0
#define UC_MODULE_CGM_AC4_DC5     0

/* AC5 CLOCK Bridge */
#define UC_MODULE_CGM_AC5         0
#define UC_MODULE_CGM_AC5_DC0     0
#define UC_MODULE_CGM_AC5_DC1     0
#define UC_MODULE_CGM_AC5_DC2     0
#define UC_MODULE_CGM_AC5_DC3     0
#define UC_MODULE_CGM_AC5_DC4     0
#define UC_MODULE_CGM_AC5_DC5     0

/* AC6 CLOCK Bridge */
#define UC_MODULE_CGM_AC6         0
#define UC_MODULE_CGM_AC6_DC0     0
#define UC_MODULE_CGM_AC6_DC1     0
#define UC_MODULE_CGM_AC6_DC2     0
#define UC_MODULE_CGM_AC6_DC3     0
#define UC_MODULE_CGM_AC6_DC4     0
#define UC_MODULE_CGM_AC6_DC5     0

/* AC7 CLOCK Bridge */
#define UC_MODULE_CGM_AC7         0
#define UC_MODULE_CGM_AC7_DC0     0
#define UC_MODULE_CGM_AC7_DC1     0
#define UC_MODULE_CGM_AC7_DC2     0
#define UC_MODULE_CGM_AC7_DC3     0
#define UC_MODULE_CGM_AC7_DC4     0
#define UC_MODULE_CGM_AC7_DC5     0

/* AC8 CLOCK Bridge */
#define UC_MODULE_CGM_AC8         0
#define UC_MODULE_CGM_AC8_DC0     0
#define UC_MODULE_CGM_AC8_DC1     0
#define UC_MODULE_CGM_AC8_DC2     0
#define UC_MODULE_CGM_AC8_DC3     0
#define UC_MODULE_CGM_AC8_DC4     0
#define UC_MODULE_CGM_AC8_DC5     0

/* AC9 CLOCK Bridge */
#define UC_MODULE_CGM_AC9         0
#define UC_MODULE_CGM_AC9_DC0     0
#define UC_MODULE_CGM_AC9_DC1     0
#define UC_MODULE_CGM_AC9_DC2     0
#define UC_MODULE_CGM_AC9_DC3     0
#define UC_MODULE_CGM_AC9_DC4     0
#define UC_MODULE_CGM_AC9_DC5     0

/* AC10 CLOCK Bridge */
#define UC_MODULE_CGM_AC10        0
#define UC_MODULE_CGM_AC10_DC0    0
#define UC_MODULE_CGM_AC10_DC1    0
#define UC_MODULE_CGM_AC10_DC2    0
#define UC_MODULE_CGM_AC10_DC3    0
#define UC_MODULE_CGM_AC10_DC4    0
#define UC_MODULE_CGM_AC10_DC5    0

/* AC11 CLOCK Bridge */
#define UC_MODULE_CGM_AC11        0
#define UC_MODULE_CGM_AC11_DC0    0
#define UC_MODULE_CGM_AC11_DC1    0
#define UC_MODULE_CGM_AC11_DC2    0
#define UC_MODULE_CGM_AC11_DC3    0
#define UC_MODULE_CGM_AC11_DC4    0
#define UC_MODULE_CGM_AC11_DC5    0

/* AC12 CLOCK Bridge */
#define UC_MODULE_CGM_AC12        0
#define UC_MODULE_CGM_AC12_DC0    0
#define UC_MODULE_CGM_AC12_DC1    0
#define UC_MODULE_CGM_AC12_DC2    0
#define UC_MODULE_CGM_AC12_DC3    0
#define UC_MODULE_CGM_AC12_DC4    0
#define UC_MODULE_CGM_AC12_DC5    0


/* ============================================================================
 * CORES SPECIFICATION
 * ==========================================================================*/

/* Number of Cores instances */
#define UC_CORE_MAX               1

/* RESET CORE: core that starts after Power On */
#define UC_RESET_CORE             0

/* CORE Enable register indexes (in register ME_CCTL, ME_CADDR) */
#define UC_CORE0_START_ID         0

/* Core0 (Main_0) Cache implementation */
#define UC_CORE0_ICHACHE          0
#define UC_CORE0_DCHACHE          0

/* ============================================================================
 * CLOCK SPECIFICATION
 * ==========================================================================*/

/* Internal oscillator value [MHz] */
#define UC_IRCOSC_CLOCK           16

/* SYSTEM_CLOCK_MAX: maximum frequency for the cores [MHz]
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations */
#define UC_SYSTEM_CLOCK_MAX       80

/* AUX CLOCK_MAX: maximum input frequency for AUX bridges [MHz]
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations */
#define UC_PLL0_PHI_CLOCK_MAX          625

/* PFBRIDGE_CLOCK_MAX: maximum frequency for M-CAN module [MHz]
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations */
#define UC_PFBRIDGE_CLOCK_MAX     40

/* SRAM CLOCK_MAX: limit that requires additional read wait state [MHz]
 * RM - Chapter 7 Device Configuration - 7.5.2.1 PRAM Wait State Management */
#define UC_SRAM_CLOCK_MAX         80

/* ----------------------------------------------------------------------------
 * CGM SC DC MAX CLOCKS (System)
 * RM Chapter 25 Clocking - 25.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_SC_DC0) /* CORE_CLK */
#define UC_CGM_SC_DC0_MAX_CLOCK   80
#endif

#if (UC_MODULE_CGM_SC_DC1) /* PBRIDGE_CLKK */
#define UC_CGM_SC_DC1_MAX_CLOCK   40
#endif

#if (UC_MODULE_CGM_SC_DC2) /* Clock Out */
#define UC_CGM_SC_DC2_MAX_CLOCK   80
#endif

#if (UC_MODULE_CGM_SC_DC3 || \
     UC_MODULE_CGM_SC_DC4 || \
     UC_MODULE_CGM_SC_DC5)
#error Forgotten SC DCx MAX Clock definition
#endif
/* --------------------------------------------------------
 * CGM AC0 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * ------------------------------------------------------*/

#if (UC_MODULE_CGM_AC0)
#define UC_CGM_AC0_MIN_CLOCK      0
#define UC_CGM_AC0_MAX_CLOCK      80
#endif

#if (UC_MODULE_CGM_AC0_DC0) /* PIT */
#define UC_CGM_AC0_DC0_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC0_DC1) /* SARADC */
#define UC_CGM_AC0_DC1_MAX_CLOCK  12
#endif

#if (UC_MODULE_CGM_AC0_DC2) /* CTU */
#define UC_CGM_AC0_DC2_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC0_DC3) /* DSPI */
#define UC_CGM_AC0_DC3_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC0_DC4) /* LINFlex */
#define UC_CGM_AC0_DC4_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC0_DC5) /* eTimer */
#define UC_CGM_AC0_DC5_MAX_CLOCK  80
#endif

/* ----------------------------------------------------------------------------
 * CGM AC1 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * ------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1)
#define UC_CGM_AC1_MIN_CLOCK      0
#define UC_CGM_AC1_MAX_CLOCK      80
#endif

#if (UC_MODULE_CGM_AC1_DC0) /* FlexCAN */
#define UC_CGM_AC1_DC0_MAX_CLOCK  40
#endif

#if (UC_MODULE_CGM_AC1_DC1 || \
     UC_MODULE_CGM_AC1_DC2 || \
	 UC_MODULE_CGM_AC1_DC3 || \
     UC_MODULE_CGM_AC1_DC4 || \
     UC_MODULE_CGM_AC1_DC5)
#error Forgotten AC1 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC2 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2)               /* PLL_0 */
#define UC_CGM_AC2_MIN_CLOCK      8
#define UC_CGM_AC2_MAX_CLOCK      56
#endif

#if (UC_MODULE_CGM_AC2_DC0 || \
	 UC_MODULE_CGM_AC2_DC1 || \
	 UC_MODULE_CGM_AC2_DC2 || \
	 UC_MODULE_CGM_AC2_DC3 || \
     UC_MODULE_CGM_AC2_DC4 || \
     UC_MODULE_CGM_AC2_DC5)
#error Forgotten AC2 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC3 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3)                /* PLL_1 */
#define UC_CGM_AC3_MIN_CLOCK      37
#define UC_CGM_AC3_MAX_CLOCK      78
#endif

#if (UC_MODULE_CGM_AC3_DC0 || \
     UC_MODULE_CGM_AC3_DC1 || \
     UC_MODULE_CGM_AC3_DC2 || \
	 UC_MODULE_CGM_AC3_DC3 || \
     UC_MODULE_CGM_AC3_DC4 || \
     UC_MODULE_CGM_AC3_DC5)
#error Forgotten AC3 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC4 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * ----------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4     || \
     UC_MODULE_CGM_AC4_DC0 || \
     UC_MODULE_CGM_AC4_DC1 || \
     UC_MODULE_CGM_AC4_DC2 || \
	 UC_MODULE_CGM_AC4_DC3 || \
     UC_MODULE_CGM_AC4_DC4 || \
     UC_MODULE_CGM_AC4_DC5)
#error Forgotten AC4 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC5 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5     || \
     UC_MODULE_CGM_AC5_DC0 || \
     UC_MODULE_CGM_AC5_DC1 || \
     UC_MODULE_CGM_AC5_DC2 || \
     UC_MODULE_CGM_AC5_DC3 || \
     UC_MODULE_CGM_AC5_DC4 || \
     UC_MODULE_CGM_AC5_DC5)
#error Forgotten AC5 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC6 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6     || \
     UC_MODULE_CGM_AC6_DC0 || \
     UC_MODULE_CGM_AC6_DC1 || \
     UC_MODULE_CGM_AC6_DC2 || \
	 UC_MODULE_CGM_AC6_DC3 || \
     UC_MODULE_CGM_AC6_DC4 || \
     UC_MODULE_CGM_AC6_DC5)
#error Forgotten AC6 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC7 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7     || \
     UC_MODULE_CGM_AC7_DC0 || \
     UC_MODULE_CGM_AC7_DC1 || \
     UC_MODULE_CGM_AC7_DC2 || \
	 UC_MODULE_CGM_AC7_DC3 || \
     UC_MODULE_CGM_AC7_DC4 || \
     UC_MODULE_CGM_AC7_DC5)
#error Forgotten AC7 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC8 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8     || \
     UC_MODULE_CGM_AC8_DC0 || \
     UC_MODULE_CGM_AC8_DC1 || \
     UC_MODULE_CGM_AC8_DC2 || \
	 UC_MODULE_CGM_AC8_DC3 || \
     UC_MODULE_CGM_AC8_DC4 || \
     UC_MODULE_CGM_AC8_DC5)
#error Forgotten AC8 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC9 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9     || \
     UC_MODULE_CGM_AC9_DC0 || \
     UC_MODULE_CGM_AC9_DC1 || \
     UC_MODULE_CGM_AC9_DC2 || \
	 UC_MODULE_CGM_AC9_DC3 || \
     UC_MODULE_CGM_AC9_DC4 || \
     UC_MODULE_CGM_AC9_DC5)
#error Forgotten AC9 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC10 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10     || \
     UC_MODULE_CGM_AC10_DC0 || \
     UC_MODULE_CGM_AC10_DC1 || \
     UC_MODULE_CGM_AC10_DC2 || \
	 UC_MODULE_CGM_AC10_DC3 || \
     UC_MODULE_CGM_AC10_DC4 || \
     UC_MODULE_CGM_AC10_DC5)
#error Forgotten AC10 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC11 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC11     || \
     UC_MODULE_CGM_AC11_DC0 || \
	 UC_MODULE_CGM_AC11_DC1 || \
     UC_MODULE_CGM_AC11_DC2 || \
	 UC_MODULE_CGM_AC11_DC3 || \
     UC_MODULE_CGM_AC11_DC4 || \
     UC_MODULE_CGM_AC11_DC5)
#error Forgotten AC11 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC12 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12     || \
     UC_MODULE_CGM_AC12_DC0 || \
	 UC_MODULE_CGM_AC12_DC1 || \
     UC_MODULE_CGM_AC12_DC2 || \
	 UC_MODULE_CGM_AC12_DC3 || \
     UC_MODULE_CGM_AC12_DC4 || \
     UC_MODULE_CGM_AC12_DC5)
#error Forgotten AC11 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM SC DC MAX DIVIDERS (System)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_SC_DC0)
#define UC_CGM_SC_DC0_MAX_DIV     8
#endif

#if (UC_MODULE_CGM_SC_DC1)
#define UC_CGM_SC_DC1_MAX_DIV     16
#endif

#if (UC_MODULE_CGM_SC_DC2)
#define UC_CGM_SC_DC2_MAX_DIV     256
#endif

#if (UC_MODULE_CGM_SC_DC3)
#define UC_CGM_SC_DC3_MAX_DIV     64
#endif

#if (UC_MODULE_CGM_SC_DC4)
#define UC_CGM_SC_DC4_MAX_DIV     64
#endif

#if (UC_MODULE_CGM_SC_DC5)
#define UC_CGM_SC_DC5_MAX_DIV     64
#endif

/* ----------------------------------------------------------------------------
 * CGM AC0 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC0_DC0) /* PIT */
#define UC_CGM_AC0_DC0_MAX_DIV    16
#endif

#if (UC_MODULE_CGM_AC0_DC1) /* SARADC */
#define UC_CGM_AC0_DC1_MAX_DIV    128
#endif

#if (UC_MODULE_CGM_AC0_DC2) /* CTU */
#define UC_CGM_AC0_DC2_MAX_DIV    128
#endif

#if (UC_MODULE_CGM_AC0_DC3) /* DSPI */
#define UC_CGM_AC0_DC3_MAX_DIV    128
#endif

#if (UC_MODULE_CGM_AC0_DC4) /* LIN */
#define UC_CGM_AC0_DC4_MAX_DIV    16
#endif

#if (UC_MODULE_CGM_AC0_DC5) /* eTimer */
#define UC_CGM_AC0_DC5_MAX_DIV    16
#endif

/* ----------------------------------------------------------------------------
 * CGM AC1 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0) /* FlexCAN */
#define UC_CGM_AC1_DC0_MAX_DIV    64
#endif

#if (UC_MODULE_CGM_AC1_DC1 || \
     UC_MODULE_CGM_AC1_DC2 || \
	 UC_MODULE_CGM_AC1_DC3 || \
     UC_MODULE_CGM_AC1_DC4 || \
     UC_MODULE_CGM_AC1_DC5)
#error Forgotten AC1 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC2 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0 || \
	 UC_MODULE_CGM_AC2_DC1 || \
	 UC_MODULE_CGM_AC2_DC2 || \
	 UC_MODULE_CGM_AC2_DC3 || \
     UC_MODULE_CGM_AC2_DC4 || \
     UC_MODULE_CGM_AC2_DC5)
#error Forgotten AC2 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC3 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3_DC0 || \
     UC_MODULE_CGM_AC3_DC1 || \
     UC_MODULE_CGM_AC3_DC2 || \
	 UC_MODULE_CGM_AC3_DC3 || \
     UC_MODULE_CGM_AC3_DC4 || \
     UC_MODULE_CGM_AC3_DC5)
#error Forgotten AC3 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC4 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4_DC0 || \
     UC_MODULE_CGM_AC4_DC1 || \
     UC_MODULE_CGM_AC4_DC2 || \
	 UC_MODULE_CGM_AC4_DC3 || \
     UC_MODULE_CGM_AC4_DC4 || \
     UC_MODULE_CGM_AC4_DC5)
#error Forgotten AC4 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC5 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0 || \
     UC_MODULE_CGM_AC5_DC1 || \
     UC_MODULE_CGM_AC5_DC2 || \
     UC_MODULE_CGM_AC5_DC3 || \
     UC_MODULE_CGM_AC5_DC4 || \
     UC_MODULE_CGM_AC5_DC5)
#error Forgotten AC5 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC6 DC MAX DIVIDERS (Peripherals)
 *
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6_DC0 || \
	 UC_MODULE_CGM_AC6_DC1 || \
     UC_MODULE_CGM_AC6_DC2 || \
	 UC_MODULE_CGM_AC6_DC3 || \
     UC_MODULE_CGM_AC6_DC4 || \
     UC_MODULE_CGM_AC6_DC5)
#error Forgotten AC6 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC7 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7_DC0 || \
     UC_MODULE_CGM_AC7_DC1 || \
     UC_MODULE_CGM_AC7_DC2 || \
	 UC_MODULE_CGM_AC7_DC3 || \
     UC_MODULE_CGM_AC7_DC4 || \
     UC_MODULE_CGM_AC7_DC5)
#error Forgotten AC7 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC8 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8_DC0 || \
     UC_MODULE_CGM_AC8_DC1 || \
     UC_MODULE_CGM_AC8_DC2 || \
	 UC_MODULE_CGM_AC8_DC3 || \
     UC_MODULE_CGM_AC8_DC4 || \
     UC_MODULE_CGM_AC8_DC5)
#error Forgotten AC8 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC9 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9_DC0 || \
     UC_MODULE_CGM_AC9_DC1 || \
     UC_MODULE_CGM_AC9_DC2 || \
	 UC_MODULE_CGM_AC9_DC3 || \
     UC_MODULE_CGM_AC9_DC4 || \
     UC_MODULE_CGM_AC9_DC5)
#error Forgotten AC9 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC10 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10_DC0 || \
     UC_MODULE_CGM_AC10_DC1 || \
     UC_MODULE_CGM_AC10_DC2 || \
	 UC_MODULE_CGM_AC10_DC3 || \
     UC_MODULE_CGM_AC10_DC4 || \
     UC_MODULE_CGM_AC10_DC5)
#error Forgotten AC10 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC11 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC11_DC0 || \
	 UC_MODULE_CGM_AC11_DC1 || \
     UC_MODULE_CGM_AC11_DC2 || \
	 UC_MODULE_CGM_AC11_DC3 || \
     UC_MODULE_CGM_AC11_DC4 || \
     UC_MODULE_CGM_AC11_DC5)
#error Forgotten AC11 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC12 DC MAX DIVIDERS
 *
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12_DC0 || \
	 UC_MODULE_CGM_AC12_DC1 || \
	 UC_MODULE_CGM_AC12_DC2 || \
	 UC_MODULE_CGM_AC12_DC3 || \
     UC_MODULE_CGM_AC12_DC4 || \
     UC_MODULE_CGM_AC12_DC5)
#error Forgotten AC12 DCx MAX divider definition
#endif


/* ============================================================================
 * SYSCLK0 OUTPUT SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_SYSCLK0)

/* SYSCLK0 AUX bridge and Divider */
#define UC_SYSCLK0_SC             0
#define UC_SYSCLK0_DC             2
#define UC_SYSCLK0_DIV_MAX        UC_CGM_SC_DC2_MAX_CLOCK

/* SYSCLK0 output pin (PORT_E:Pin_5) */
#define UC_SYSCLK0_PIN            69

#endif


/* ============================================================================
 * SYSCLK1 OUTPUT SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_SYSCLK1)

/* SYSCLK1 AUX bridge and Divider */
#define UC_SYSCLK1_AUX            7
#define UC_SYSCLK1_DC             0
#define UC_SYSCLK1_DIV_MAX        UC_CGM_AC7_DC0_MAX_DIV

/* SYSCLK1 output pin (PORT_A:Pin_15 */
#define UC_SYSCLK1_PIN            15

#endif


/* ============================================================================
 * PFLASH SPECIFICATION
 * ==========================================================================*/

/* PFLASH selection of minimum Wait states for given SYSTEM_CLOCK
 * DS Chapter 3.16 - Flash Memory */
#define UC_PFLASH_3_WS_CLOCK      80
#define UC_PFLASH_2_WS_CLOCK      64
#define UC_PFLASH_1_WS_CLOCK      40
#define UC_PFLASH_0_WS_CLOCK      20


/* PFLASH minimum wait states needed based on SYSTEM_CLOCK setting */
#if (UC_SYSTEM_CLOCK > UC_PFLASH_3_WS_CLOCK)
#define UC_PFLASH_WS_MIN  4
#elif (UC_SYSTEM_CLOCK > UC_PFLASH_2_WS_CLOCK)
#define UC_PFLASH_WS_MIN  3
#elif (UC_SYSTEM_CLOCK > UC_PFLASH_1_WS_CLOCK)
#define UC_PFLASH_WS_MIN  2
#elif (UC_SYSTEM_CLOCK > UC_PFLASH_0_WS_CLOCK)
#define UC_PFLASH_WS_MIN  1
#else
#define UC_PFLASH_WS_MIN  0
#endif


/* ============================================================================
 * PRAM SPECIFICATION
 * ==========================================================================*/

/* SRAM  Wait states for Read access  */
#define UC_PRAM_FT_DIS           0


/* ============================================================================
 * PLL0 SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_PLL0)

/* PLL0 parameters
 * DS Chapter 4.15  PLL0/PLL1 electrical characteristics */
#define UC_PLL0_INCLK_MIN         8
#define UC_PLL0_INCLK_MAX         56
#define UC_PLL0_VCO_MIN           600
#define UC_PLL0_VCO_MAX           1250

/* PLL1 DV register boundaries */
#define UC_PLL0_MFD_MIN            8
#define UC_PLL0_MFD_MAX            127

#endif


/* ============================================================================
 * PLL1 SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_PLL1)

/* PLL1 parameters
 *  */
#define UC_PLL1_INCLK_MIN         37
#define UC_PLL1_INCLK_MAX         78
#define UC_PLL1_VCO_MIN           600
#define UC_PLL1_VCO_MAX           1250

/* PLL1 DV register boundaries */
#define UC_PLL1_MFD_MIN            16
#define UC_PLL1_MFD_MAX            34

#endif


/* ============================================================================
 * PIT SPECIFICATION
 * ==========================================================================*/

/* Number of channel instances for PIT_0 */
#define UC_MODULE_PIT_CHANNELS    4

/* PIT Timer Channel 0 ISR Vector (base vector for subsequent channels) */
#define UC_PIT_CH0_ISR_VECTOR     226


/* ============================================================================
 * MODULE BASE ADDRESSES IN MEMORY MAP
 * use of semiconductor peripheral file
 * ==========================================================================*/

#if (UC_MODULE_ME)
#define UC_ME_BASE                (uint32_t) &MC_ME
#endif

#if (UC_MODULE_INTC)
#define UC_INTC                   (uint32_t) &INTC_0
#endif

#if (UC_MODULE_CGM)
#define UC_CGM                    (uint32_t) &MC_CGM
#endif

#if (UC_MODULE_PLL0 | UC_MODULE_PLL1)
#define UC_PLL_BASE               (uint32_t) &PLLDIG
#endif

#if (UC_MODULE_PFLASH0)
#define	UC_PFLASH0_BASE           (uint32_t) &PFLASH_0
#endif

#if (UC_MODULE_PFLASH1)
#define	UC_PFLASH1_BASE           (uint32_t) &PFLASH_1
#endif

#if (UC_MODULE_PRAM0)
#define	UC_PRAM0_BASE             (uint32_t) &PRAM_0
#endif

#if (UC_MODULE_PRAM1)
#define	UC_PRAM1_BASE             (uint32_t) &PRAM_1
#endif

#if (UC_MODULE_PRAM2)
#define	UC_PRAM2_BASE             (uint32_t) &PRAM_2
#endif

#if (UC_MODULE_PRAM3)
#define	UC_PRAM3_BASE             (uint32_t) &PRAM_3
#endif

#if (UC_MODULE_SWT0)
#define UC_SWT0_BASE              (uint32_t) &SWT_0
#endif

#if (UC_MODULE_SWT1)
#define UC_SWT1_BASE              (uint32_t) &SWT_1
#endif

#if (UC_MODULE_SWT2)
#define UC_SWT2_BASE              (uint32_t) &SWT_2
#endif

#if (UC_MODULE_SWT3)
#define UC_SWT3_BASE              (uint32_t) &SWT_3
#endif

#if (UC_MODULE_PIT0)
#define	UC_PIT0_BASE              (uint32_t) &PIT_0
#endif

#if (UC_MODULE_SIUL)
#define UC_SIUL_BASE              (uint32_t) &SIUL2
#endif



/* ============================================================================
 * PLL SUBSYSTEM CALCULATION
 * ==========================================================================*/

/* ----------------------------------------------------------------------------
 * PLL1 CALCULATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL1)

/* Selection of PLL1_IN_CLOCK generated from PLL0
 * 40 MHz : allows going to lower system clock frequency setting
 * 80 MHz : allows wider set of AUX_CLOCKs,
 *          but in that case SYSTEM CLOCK of PLL1 must be set higher */
#if ((UC_PLL0_PHI_CLOCK == 80))
#define UC_PLL1_IN_CLOCK          48
#else
#error Other PLL1 input clocks are not supported, please use your own PLL initialization
#endif

/* PLL1 MIN values to make following macros readable */
#define PLL1_VCO_MIN (UC_PLL1_VCO_MIN-1)
#define PLL1_VCO_MAX (UC_PLL1_VCO_MAX+1)
#define PLL1_MFD_MIN (UC_PLL1_MFD_MIN-1)

/* PLL1 parameters
 * 3 default PLL1 configurations that should fit most of the SYSTEM_CLOCK.
 * If not, than the USer must provide its own HW platform initialization and
 * switch off the default configuration by defining BSP_HW_INIT_CHECK=0 */

/* PLL1_VCO_A : RFPDHI = 12 */
#define PLL1_VCO_A                (UC_SYSTEM_CLOCK * 12)
#define PLL1_MFD_A                (PLL1_VCO_A / UC_PLL1_IN_CLOCK)
#define PLL1_MFD_A_NOT_VALID      ((PLL1_MFD_A * UC_PLL1_IN_CLOCK)-PLL1_VCO_A)
#if ( (PLL1_VCO_A < PLL1_VCO_MAX) && (PLL1_VCO_A > PLL1_VCO_MIN) && (PLL1_MFD_A > PLL1_MFD_MIN) && !PLL1_MFD_A_NOT_VALID )
#define PLL1_RFDPHI               12
#define PLL1_MFD                  PLL1_MFD_A

#else /* PLL1_VCO_A not valid, try PLL1_VCO_B : RFDPHI = 16 */
#define PLL1_VCO_B                (UC_SYSTEM_CLOCK * 16)
#define PLL1_MFD_B                (PLL1_VCO_B / UC_PLL1_IN_CLOCK)
#define PLL1_MFD_B_NOT_VALID      ((PLL1_MFD_B * UC_PLL1_IN_CLOCK)-PLL1_VCO_B)
#if ( (PLL1_VCO_B < PLL1_VCO_MAX) && (PLL1_VCO_B > PLL1_VCO_MIN) && (PLL1_MFD_B > PLL1_MFD_MIN) && !PLL1_MFD_B_NOT_VALID )
#define PLL1_RFDPHI               16
#define PLL1_MFD                  PLL1_MFD_B

#else /* PLL1_VCO_B not valid, try PLL1_VCO_C : RFDPHI = 24*/
#define PLL1_VCO_C                (UC_SYSTEM_CLOCK * 24)
#define PLL1_MFD_C                (PLL1_VCO_C / UC_PLL1_IN_CLOCK)
#define PLL1_MFD_C_NOT_VALID      ((PLL1_MFD_C * UC_PLL1_IN_CLOCK)-PLL1_VCO_C)
#if ( (PLL1_VCO_C < PLL1_VCO_MAX) && (PLL1_VCO_C > PLL1_VCO_MIN) && (PLL1_MFD_C > PLL1_MFD_MIN) && !PLL1_MFD_C_NOT_VALID )
#define PLL1_RFDPHI               24
#define PLL1_MFD                  PLL1_MFD_C

#else /* Simple algorithm has not found a solution */
#if (BSP_HW_INIT_CHECK)
#error PLL1 setting cannot be found, try different combination of SYSTEM_CLOCK and AUX_CLOCK, \
	   or switch off the default BSP HW initialization and implement \
       your own HW initialization (use directly LLD API)
#endif /* #if BSP_HW_INIT_CHECK */

#endif /* PLL1_VCO_C */
#endif /* PLL1_VCO_B */
#endif /* PLL1_VCO_A */

#endif /* UC_MODULE_PLL1 */

/* ----------------------------------------------------------------------------
 * PLL0 CALCULATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL0)

/* PLL0 MIN values to make following macros more readable */
#define PLL0_VCO_MIN              (UC_PLL0_VCO_MIN)
#define PLL0_VCO_MAX              (UC_PLL0_VCO_MAX)

/* Direct setting, they should be within uC parameters limits by any case */
#define PLL0_RFDPHI1              15
#define PLL0_VCO                  (PLL0_RFDPHI1 * UC_PLL1_IN_CLOCK)
#define PLL0_RFDPHI               (PLL0_VCO / UC_PLL0_PHI_CLOCK)
#define PLL0_MFD                  (PLL0_VCO / UC_XTAL_CLOCK)
#define PLL0_PREDIV               1

/* Check PLL0 VCO frequency */
#if ((PLL0_VCO > PLL0_VCO_MAX) || (PLL0_VCO < PLL0_VCO_MIN))
#error PLL0 VCO is out of the range
#endif

/* Check RFDPHI setting, if it is a whole integer */
#if ((PLL0_RFDPHI * UC_PLL0_PHI_CLOCK) - PLL0_VCO)
#error PLL0 clock setting is not exact, check is needed
#endif

/* PLL0 parameters setting */
#define UC_PLL0_PREDIV            PLL0_PREDIV
#define UC_PLL0_MFD               PLL0_MFD
#define UC_PLL0_RFDPHI            PLL0_RFDPHI
#define UC_PLL0_RFDPHI1           PLL0_RFDPHI1

#endif


/* ============================================================================
 * uC BSP TYPES INCLUDE
 * ==========================================================================*/

#include "uc_spc570s50_types.h"


/* ============================================================================
 * PLATFORM CONFIGURATION
 * Optimal platform setting for configured clocks
 * ==========================================================================*/

/* Desired System clock selection from UC_ME_MODE_SYSCLK_e */
#define UC_SYSTEM_CLOCK_SEL       UC_ME_MODE_SYSCLK_PLL1_PHI


/* ----------------------------------------------------------------------------
 * PLL0 CONFIGURATION
 * calculated ones
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL0)

#define UC_PLL0_PREDIV            PLL0_PREDIV
#define UC_PLL0_MFD               PLL0_MFD
#define UC_PLL0_RFDPHI            PLL0_RFDPHI
#define UC_PLL0_RFDPHI1           PLL0_RFDPHI1

#endif

/* ----------------------------------------------------------------------------
 * PLL1 CONFIGURATION
 * calculated ones
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL1)

#define UC_PLL1_MFD               PLL1_MFD
#define UC_PLL1_RFDPHI            PLL1_RFDPHI

#endif

/* ----------------------------------------------------------------------------
 * PFLASH0 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PFLASH0)

/* PFCR1 */
#define UC_PFLASH0_PFCR1_APC      UC_PFLASH_APC_PIPELINE_DIS
#define UC_PFLASH0_PFCR1_WS       UC_PFLASH_WS_MIN
#define UC_PFLASH0_PFCR1_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR2 */
#define UC_PFLASH0_PFCR2_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR3 */
#define UC_PFLASH0_PFCR3_P0WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH0_PFCR3_P1WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH0_PFCR3_ARB      UC_PFLASH_ARBM_FIXED_PRIO_P0_P1

#endif

/* ----------------------------------------------------------------------------
 * PFLASH1 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PFLASH1)

/* PFCR1 */
#define UC_PFLASH1_PFCR1_APC      UC_PFLASH_APC_PIPELINE_DIS
#define UC_PFLASH1_PFCR1_WS       UC_PFLASH_WS_MIN
#define UC_PFLASH1_PFCR1_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR2 */
#define UC_PFLASH1_PFCR2_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR3 */
#define UC_PFLASH1_PFCR3_P0WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH1_PFCR3_P1WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH1_PFCR3_ARB      UC_PFLASH_ARBM_FIXED_PRIO_P0_P1

#endif

/* ----------------------------------------------------------------------------
 * PRAM0 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM0)

#define UC_PRAM0_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM0_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM0_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM0_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * PRAM1 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM1)

#define UC_PRAM1_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM1_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM1_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM1_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * PRAM2 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM2)

#define UC_PRAM2_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM2_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM2_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM2_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * PRAM3 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM3)

#define UC_PRAM3_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM3_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM3_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM3_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * CGM CLOCK AUX BRIDGES CONFIGURATION
 * --------------------------------------------------------------------------*/

/* System clock dividers */
#define UC_CGM_CORE_CLK_DIV       1

/* Peripheral clock dividers */
#define UC_PBRIDGE_CLK_DIV        (UC_SYSTEM_CLOCK   / UC_PBRIDGE_CLK)
#define UC_PER_CLK0_DIV           (UC_PLL0_PHI_CLOCK / UC_PER_CLK0)
#define UC_SARADC_CLK_DIV         (UC_PLL0_PHI_CLOCK / UC_SARADC_CLK)
#define UC_CTU_CLK_DIV            (UC_PLL0_PHI_CLOCK / UC_CTU_CLK)
#define UC_DSPI_CLK_DIV           (UC_PLL0_PHI_CLOCK / UC_DSPI_CLK)
#define UC_LIN_CLK_DIV            (UC_PLL0_PHI_CLOCK / UC_LIN_CLK)
#define UC_ETIMER_CLK_DIV         (UC_PLL0_PHI_CLOCK / UC_ETIMER_CLK)
#define UC_CAN_CLK_DIV            (UC_PLL0_PHI_CLOCK / UC_CAN_CLK)


/* AC Clock Selection - one common group */
#define UC_CGM_AC_CLKSEL_IRCOSC        0
#define UC_CGM_AC_CLKSEL_XOSC          1
#define UC_CGM_AC_CLKSEL_PLL0_PHI      2
#define UC_CGM_AC_CLKSEL_PLL0_PHI1     3
#define UC_CGM_AC_CLKSEL_PLL1_PHI      4
#define UC_CGM_AC_CLKSEL_LFAST_PIN     5

/* ----------------------------------------------------------------------------
 * SC DC
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_SC_DC0) /* CORE_CLK */
#define UC_CGM_SC_DC0_INIT       1
#define UC_CGM_SC_DC0_DIV        UC_CGM_CORE_CLK_DIV
#endif

#if (UC_MODULE_CGM_SC_DC1) /* PBRIDGE_CLK */
#define UC_CGM_SC_DC1_INIT       1
#define UC_CGM_SC_DC1_DIV        UC_PBRIDGE_CLK_DIV
#endif

#if (UC_MODULE_CGM_SC_DC2) /* Clock Out */
#define UC_CGM_SC_DC2_INIT       1
#define UC_CGM_SC_DC2_DIV        10
#endif

#if (UC_MODULE_CGM_SC_DC3 || \
     UC_MODULE_CGM_SC_DC4 || \
	 UC_MODULE_CGM_SC_DC5)
#error Forgotten initialization of SC Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC0
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC0)
#define UC_CGM_AC0_INIT           1
#define UC_CGM_AC0_CLOCK_INPUT    UC_CGM_AC_CLKSEL_PLL0_PHI
#define UC_CGM_AC0_CLOCK_VALUE    UC_PLL0_PHI_CLOCK
#endif

#if (UC_MODULE_CGM_AC0_DC0) /* PIT_CLK */
#define UC_CGM_AC0_DC0_INIT       1
#define UC_CGM_AC0_DC0_DIV        UC_PER_CLK0_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC1) /* SARADC_CLK */
#define UC_CGM_AC0_DC1_INIT       1
#define UC_CGM_AC0_DC1_DIV        UC_SARADC_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC2) /* CTU_CLK */
#define UC_CGM_AC0_DC2_INIT       1
#define UC_CGM_AC0_DC2_DIV        UC_CTU_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC3) /* DSPI_CLK */
#define UC_CGM_AC0_DC3_INIT       1
#define UC_CGM_AC0_DC3_DIV        UC_DSPI_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC4) /* LIN_CLK */
#define UC_CGM_AC0_DC4_INIT       1
#define UC_CGM_AC0_DC4_DIV        UC_LIN_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC5) /* ETIMER_CLK */
#define UC_CGM_AC0_DC5_INIT       1
#define UC_CGM_AC0_DC5_DIV        UC_ETIMER_CLK_DIV
#endif


/* ----------------------------------------------------------------------------
 * AC1
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1)
#define UC_CGM_AC1_INIT           1
#define UC_CGM_AC1_CLOCK_INPUT    UC_CGM_AC_CLKSEL_PLL0_PHI
#define UC_CGM_AC1_CLOCK_VALUE    UC_PLL0_PHI_CLOCK
#endif

#if (UC_MODULE_CGM_AC1_DC0) /* CAN */
#define UC_CGM_AC1_DC0_INIT       1
#define UC_CGM_AC1_DC0_DIV        UC_CAN_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC1_DC1 || \
     UC_MODULE_CGM_AC1_DC2 || \
	 UC_MODULE_CGM_AC1_DC3 || \
     UC_MODULE_CGM_AC1_DC4 || \
	 UC_MODULE_CGM_AC1_DC5)
#error Forgotten initialization of AC1 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC2
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2)
#define UC_CGM_AC2_INIT           1
#define UC_CGM_AC2_CLOCK_INPUT    UC_CGM_AC_CLKSEL_XOSC
#define UC_CGM_AC2_CLOCK_VALUE    UC_XTAL_CLOCK
#endif

#if (UC_MODULE_CGM_AC2_DC0 || \
	 UC_MODULE_CGM_AC2_DC1 || \
     UC_MODULE_CGM_AC2_DC2 || \
	 UC_MODULE_CGM_AC2_DC3 || \
     UC_MODULE_CGM_AC2_DC4 || \
	 UC_MODULE_CGM_AC2_DC5)
#error Forgotten initialization of AC1 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC3
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3)
#define UC_CGM_AC3_INIT           1
#define UC_CGM_AC3_CLOCK_INPUT    UC_CGM_AC_CLKSEL_PLL0_PHI1
#define UC_CGM_AC3_CLOCK_VALUE    UC_PLL1_IN_CLOCK
#endif

#if (UC_MODULE_CGM_AC3_DC0 || \
     UC_MODULE_CGM_AC3_DC1 || \
     UC_MODULE_CGM_AC3_DC2 || \
	 UC_MODULE_CGM_AC3_DC3 || \
     UC_MODULE_CGM_AC3_DC4 || \
	 UC_MODULE_CGM_AC3_DC5)
#error Forgotten initialization of AC3 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC4
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4     || \
     UC_MODULE_CGM_AC4_DC0 || \
     UC_MODULE_CGM_AC4_DC1 || \
     UC_MODULE_CGM_AC4_DC2 || \
	 UC_MODULE_CGM_AC4_DC3 || \
     UC_MODULE_CGM_AC4_DC4 || \
	 UC_MODULE_CGM_AC4_DC5)
#error Forgotten initialization of AC4 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC5
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5     || \
     UC_MODULE_CGM_AC5_DC0 || \
     UC_MODULE_CGM_AC5_DC1 || \
     UC_MODULE_CGM_AC5_DC2 || \
	 UC_MODULE_CGM_AC5_DC3 || \
     UC_MODULE_CGM_AC5_DC4 || \
	 UC_MODULE_CGM_AC5_DC5)
#error Forgotten initialization of AC5 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC6
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6     || \
     UC_MODULE_CGM_AC6_DC0 || \
	 UC_MODULE_CGM_AC6_DC1 || \
     UC_MODULE_CGM_AC6_DC2 || \
	 UC_MODULE_CGM_AC6_DC3 || \
     UC_MODULE_CGM_AC6_DC4 || \
	 UC_MODULE_CGM_AC6_DC5)
#error Forgotten initialization of AC6 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC7
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7 || \
     UC_MODULE_CGM_AC7_DC0 || \
	 UC_MODULE_CGM_AC7_DC1 || \
     UC_MODULE_CGM_AC7_DC2 || \
	 UC_MODULE_CGM_AC7_DC3 || \
     UC_MODULE_CGM_AC7_DC4 || \
	 UC_MODULE_CGM_AC7_DC5)
#error Forgotten initialization of AC7 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC8
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8     || \
     UC_MODULE_CGM_AC8_DC0 || \
	 UC_MODULE_CGM_AC8_DC1 || \
     UC_MODULE_CGM_AC8_DC2 || \
	 UC_MODULE_CGM_AC8_DC3 || \
     UC_MODULE_CGM_AC8_DC4 || \
	 UC_MODULE_CGM_AC8_DC5)
#error Forgotten initialization of AC8 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC9
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9 || \
     UC_MODULE_CGM_AC9_DC0 || \
	 UC_MODULE_CGM_AC9_DC1 || \
     UC_MODULE_CGM_AC9_DC2 || \
	 UC_MODULE_CGM_AC9_DC3 || \
     UC_MODULE_CGM_AC9_DC4 || \
	 UC_MODULE_CGM_AC9_DC5)
#error Forgotten initialization of AC9 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC10
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10 || \
     UC_MODULE_CGM_AC10_DC0 || \
	 UC_MODULE_CGM_AC10_DC1 || \
     UC_MODULE_CGM_AC10_DC2 || \
	 UC_MODULE_CGM_AC10_DC3 || \
     UC_MODULE_CGM_AC10_DC4 || \
	 UC_MODULE_CGM_AC10_DC5)
#error Forgotten initialization of AC10 Dividers
#endif

/* --------------------------------------------------------
 * AC11
 * ------------------------------------------------------*/

#if (UC_MODULE_CGM_AC11     || \
	 UC_MODULE_CGM_AC11_DC0 || \
     UC_MODULE_CGM_AC11_DC1 || \
	 UC_MODULE_CGM_AC11_DC2 || \
	 UC_MODULE_CGM_AC11_DC3 || \
     UC_MODULE_CGM_AC11_DC4 || \
	 UC_MODULE_CGM_AC11_DC5)
#error Forgotten initialization of AC11 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC12
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12     || \
     UC_MODULE_CGM_AC12_DC0 || \
     UC_MODULE_CGM_AC12_DC1 || \
     UC_MODULE_CGM_AC12_DC2 || \
	 UC_MODULE_CGM_AC12_DC3 || \
     UC_MODULE_CGM_AC12_DC4 || \
	 UC_MODULE_CGM_AC12_DC5)
#error Forgotten initialization of AC12 Dividers
#endif

/* ----------------------------------------------------------------------------
 * SYSTEM CLOCK 0 OUTPUT CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_SYSCLK0)

/* Default Clock Selection for SYSCLK0 */
#ifndef UC_SYSCLK0_SEL
#define UC_SYSCLK0_SEL            UC_SYSCLK0_SELCTL_PLL0_PHI
#endif

/* Default Divider for Selected clock output*/
#ifndef UC_SYSCLK0_DIV
#define UC_SYSCLK0_DIV            10
#endif

#endif

/* ----------------------------------------------------------------------------
 * SYSTEM CLOCK 1 OUTPUT CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_SYSCLK1)

/* Default Clock Selection for SYSCLK1 */
#ifndef UC_SYSCLK1_SEL
#define UC_SYSCLK1_SEL            UC_SYSCLK1_SELCTL_PLL0_PHI
#endif

/* Default Divider for Selected clock output*/
#ifndef UC_SYSCLK1_DIV
#define UC_SYSCLK1_DIV            10
#endif

#endif


/* ============================================================================
 * uC CONFIGURATION CHECKS
 * ==========================================================================*/

#if (BSP_HW_INIT_CHECK)

/* ----------------------------------------------------------------------------
 * SYSTEM CLOCKS
 * --------------------------------------------------------------------------*/

/* check of System Clock configuration */
#if (UC_SYSTEM_CLOCK > UC_SYSTEM_CLOCK_MAX)
#error SYS_CLOCK is higher than architecture maximum
#endif

/* check of AUX Clock configuration */
#if (UC_PLL0_PHI_CLOCK > UC_PLL0_PHI_CLOCK_MAX)
#error AUX_CLOCK is higher than architecture maximum
#endif

/* Check of XTAL range for PLL0 */
#if ((UC_XTAL_CLOCK < UC_PLL0_INCLK_MIN) || (UC_XTAL_CLOCK > UC_PLL0_INCLK_MAX))
#error XTAL_CLOCK setting is out of permitted boundary
#endif

/* ----------------------------------------------------------------------------
 * SYSCLK OUTPUTS
 * --------------------------------------------------------------------------*/

/* SYSCLK0 Divider maximum check */
#if (UC_SYSCLK0_DIV > UC_SYSCLK0_DIV_MAX)
#error SYSCLK0 divider > MAX
#endif

/* SYSCLK1 Divider maximum check */
#if (UC_SYSCLK1_DIV > UC_SYSCLK1_DIV_MAX)
#error SYSCLK1 divider > MAX
#endif

/* ----------------------------------------------------------------------------
 * SUPPORTED MODULE CLOCKS DIVIDERS
 * Dividers must be a whole integer to get precise
 * user specified clock
 * --------------------------------------------------------------------------*/

/* SARADC whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_SARADC_CLK_DIV * UC_SARADC_CLK))
#error SARADC clock is not exact, divider is not a whole number. Check the setting
#endif

/* PIT_CLK whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_PER_CLK0_DIV * UC_PER_CLK0))
#error PIT clock is not exact, divider is not a whole number. Check the setting
#endif

/* CTU_CLK whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_CTU_CLK_DIV * UC_CTU_CLK))
#error CTU clock is not exact, divider is not a whole number. Check the setting
#endif

/* DSPI_CLK whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_DSPI_CLK_DIV * UC_DSPI_CLK))
#error DSPI_CLK clock is not exact, divider is not a whole number. Check the setting
#endif

/* LIN_CLK whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_LIN_CLK_DIV * UC_LIN_CLK))
#error LIN_CLK clock is not exact, divider is not a whole number. Check the setting
#endif

/* CAN_CLK whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_CAN_CLK_DIV * UC_CAN_CLK))
#error CAN_CLK clock is not exact, divider is not a whole number. Check the setting
#endif

/* eTimer whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_ETIMER_CLK_DIV * UC_ETIMER_CLK))
#error eTimer clock is not exact, divider is not a whole number. Check the setting
#endif

/* ----------------------------------------------------------------------------
 * AC1 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0)
#if (UC_CGM_AC1_DC0_DIV > UC_CGM_AC1_DC0_MAX_DIV)
#error AC1_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC1)
#if (UC_CGM_AC1_DC1_DIV > UC_CGM_AC1_DC1_MAX_DIV)
#error AC1_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC2)
#if (UC_CGM_AC1_DC2_DIV > UC_CGM_AC1_DC2_MAX_DIV)
#error AC1_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC3)
#if (UC_CGM_AC1_DC3_DIV > UC_CGM_AC1_DC3_MAX_DIV)
#error AC1_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC4)
#if (UC_CGM_AC1_DC4_DIV > UC_CGM_AC1_DC4_MAX_DIV)
#error AC1_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC5)
#if (UC_CGM_AC1_DC5_DIV > UC_CGM_AC1_DC5_MAX_DIV)
#error AC1_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC2 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0)
#if (UC_CGM_AC2_DC0_DIV > UC_CGM_AC2_DC0_MAX_DIV)
#error AC2_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC1)
#if (UC_CGM_AC2_DC1_DIV > UC_CGM_AC2_DC1_MAX_DIV)
#error AC2_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC2)
#if (UC_CGM_AC2_DC2_DIV > UC_CGM_AC2_DC2_MAX_DIV)
#error AC2_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC3)
#if (UC_CGM_AC2_DC3_DIV > UC_CGM_AC2_DC3_MAX_DIV)
#error AC2_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC4)
#if (UC_CGM_AC2_DC4_DIV > UC_CGM_AC2_DC4_MAX_DIV)
#error AC2_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC5)
#if (UC_CGM_AC2_DC5_DIV > UC_CGM_AC2_DC5_MAX_DIV)
#error AC2_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC2 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0)
#if (UC_CGM_AC2_DC0_DIV > UC_CGM_AC2_DC0_MAX_DIV)
#error AC2_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC1)
#if (UC_CGM_AC2_DC1_DIV > UC_CGM_AC2_DC1_MAX_DIV)
#error AC2_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC2)
#if (UC_CGM_AC2_DC2_DIV > UC_CGM_AC2_DC2_MAX_DIV)
#error AC2_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC3)
#if (UC_CGM_AC2_DC3_DIV > UC_CGM_AC2_DC3_MAX_DIV)
#error AC2_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC4)
#if (UC_CGM_AC2_DC4_DIV > UC_CGM_AC2_DC4_MAX_DIV)
#error AC2_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC5)
#if (UC_CGM_AC2_DC5_DIV > UC_CGM_AC2_DC5_MAX_DIV)
#error AC2_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC3 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3_DC0)
#if (UC_CGM_AC3_DC0_DIV > UC_CGM_AC3_DC0_MAX_DIV)
#error AC3_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC1)
#if (UC_CGM_AC3_DC1_DIV > UC_CGM_AC3_DC1_MAX_DIV)
#error AC3_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC2)
#if (UC_CGM_AC3_DC2_DIV > UC_CGM_AC3_DC2_MAX_DIV)
#error AC3_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC3)
#if (UC_CGM_AC3_DC3_DIV > UC_CGM_AC3_DC3_MAX_DIV)
#error AC3_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC4)
#if (UC_CGM_AC3_DC4_DIV > UC_CGM_AC3_DC4_MAX_DIV)
#error AC3_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC5)
#if (UC_CGM_AC3_DC5_DIV > UC_CGM_AC3_DC5_MAX_DIV)
#error AC3_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC4 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4_DC0)
#if (UC_CGM_AC4_DC0_DIV > UC_CGM_AC4_DC0_MAX_DIV)
#error AC4_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC1)
#if (UC_CGM_AC4_DC1_DIV > UC_CGM_AC4_DC1_MAX_DIV)
#error AC4_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC2)
#if (UC_CGM_AC4_DC2_DIV > UC_CGM_AC4_DC2_MAX_DIV)
#error AC4_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC3)
#if (UC_CGM_AC4_DC3_DIV > UC_CGM_AC4_DC3_MAX_DIV)
#error AC4_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC4)
#if (UC_CGM_AC4_DC4_DIV > UC_CGM_AC4_DC4_MAX_DIV)
#error AC4_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC5)
#if (UC_CGM_AC4_DC5_DIV > UC_CGM_AC4_DC5_MAX_DIV)
#error AC4_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC5 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0)
#if (UC_CGM_AC5_DC0_DIV > UC_CGM_AC5_DC0_MAX_DIV)
#error AC5_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC1)
#if (UC_CGM_AC5_DC1_DIV > UC_CGM_AC5_DC1_MAX_DIV)
#error AC5_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC2)
#if (UC_CGM_AC5_DC2_DIV > UC_CGM_AC5_DC2_MAX_DIV)
#error AC5_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC3)
#if (UC_CGM_AC5_DC3_DIV > UC_CGM_AC5_DC3_MAX_DIV)
#error AC5_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC4)
#if (UC_CGM_AC5_DC4_DIV > UC_CGM_AC5_DC4_MAX_DIV)
#error AC5_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC5)
#if (UC_CGM_AC5_DC5_DIV > UC_CGM_AC5_DC5_MAX_DIV)
#error AC5_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC5 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0)
#if (UC_CGM_AC5_DC0_DIV > UC_CGM_AC5_DC0_MAX_DIV)
#error AC5_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC1)
#if (UC_CGM_AC5_DC1_DIV > UC_CGM_AC5_DC1_MAX_DIV)
#error AC5_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC2)
#if (UC_CGM_AC5_DC2_DIV > UC_CGM_AC5_DC2_MAX_DIV)
#error AC5_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC3)
#if (UC_CGM_AC5_DC3_DIV > UC_CGM_AC5_DC3_MAX_DIV)
#error AC5_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC4)
#if (UC_CGM_AC5_DC4_DIV > UC_CGM_AC5_DC4_MAX_DIV)
#error AC5_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC5)
#if (UC_CGM_AC5_DC5_DIV > UC_CGM_AC5_DC5_MAX_DIV)
#error AC5_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC6 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6_DC0)
#if (UC_CGM_AC6_DC0_DIV > UC_CGM_AC6_DC0_MAX_DIV)
#error AC6_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC1)
#if (UC_CGM_AC6_DC1_DIV > UC_CGM_AC6_DC1_MAX_DIV)
#error AC6_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC2)
#if (UC_CGM_AC6_DC2_DIV > UC_CGM_AC6_DC2_MAX_DIV)
#error AC6_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC3)
#if (UC_CGM_AC6_DC3_DIV > UC_CGM_AC6_DC3_MAX_DIV)
#error AC6_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC4)
#if (UC_CGM_AC6_DC4_DIV > UC_CGM_AC6_DC4_MAX_DIV)
#error AC6_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC5)
#if (UC_CGM_AC6_DC5_DIV > UC_CGM_AC6_DC5_MAX_DIV)
#error AC6_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC7 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7_DC0)
#if (UC_CGM_AC7_DC0_DIV > UC_CGM_AC7_DC0_MAX_DIV)
#error AC7_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC1)
#if (UC_CGM_AC7_DC1_DIV > UC_CGM_AC7_DC1_MAX_DIV)
#error AC7_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC2)
#if (UC_CGM_AC7_DC2_DIV > UC_CGM_AC7_DC2_MAX_DIV)
#error AC7_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC3)
#if (UC_CGM_AC7_DC3_DIV > UC_CGM_AC7_DC3_MAX_DIV)
#error AC7_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC4)
#if (UC_CGM_AC7_DC4_DIV > UC_CGM_AC7_DC4_MAX_DIV)
#error AC7_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC5)
#if (UC_CGM_AC7_DC5_DIV > UC_CGM_AC7_DC5_MAX_DIV)
#error AC7_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC8 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8_DC0)
#if (UC_CGM_AC8_DC0_DIV > UC_CGM_AC8_DC0_MAX_DIV)
#error AC8_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC1)
#if (UC_CGM_AC8_DC1_DIV > UC_CGM_AC8_DC1_MAX_DIV)
#error AC8_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC2)
#if (UC_CGM_AC8_DC2_DIV > UC_CGM_AC8_DC2_MAX_DIV)
#error AC8_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC3)
#if (UC_CGM_AC8_DC3_DIV > UC_CGM_AC8_DC3_MAX_DIV)
#error AC8_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC4)
#if (UC_CGM_AC8_DC4_DIV > UC_CGM_AC8_DC4_MAX_DIV)
#error AC8_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC5)
#if (UC_CGM_AC8_DC5_DIV > UC_CGM_AC8_DC5_MAX_DIV)
#error AC8_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC9 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9_DC0)
#if (UC_CGM_AC9_DC0_DIV > UC_CGM_AC9_DC0_MAX_DIV)
#error AC9_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC1)
#if (UC_CGM_AC9_DC1_DIV > UC_CGM_AC9_DC1_MAX_DIV)
#error AC9_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC2)
#if (UC_CGM_AC9_DC2_DIV > UC_CGM_AC9_DC2_MAX_DIV)
#error AC9_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC3)
#if (UC_CGM_AC9_DC3_DIV > UC_CGM_AC9_DC3_MAX_DIV)
#error AC9_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC4)
#if (UC_CGM_AC9_DC4_DIV > UC_CGM_AC9_DC4_MAX_DIV)
#error AC9_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC5)
#if (UC_CGM_AC9_DC5_DIV > UC_CGM_AC9_DC5_MAX_DIV)
#error AC9_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC1210 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1210_DC0)
#if (UC_CGM_AC1210_DC0_DIV > UC_CGM_AC1210_DC0_MAX_DIV)
#error AC1210_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC1)
#if (UC_CGM_AC1210_DC1_DIV > UC_CGM_AC1210_DC1_MAX_DIV)
#error AC1210_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC2)
#if (UC_CGM_AC1210_DC2_DIV > UC_CGM_AC1210_DC2_MAX_DIV)
#error AC1210_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC3)
#if (UC_CGM_AC1210_DC3_DIV > UC_CGM_AC1210_DC3_MAX_DIV)
#error AC1210_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC4)
#if (UC_CGM_AC1210_DC4_DIV > UC_CGM_AC1210_DC4_MAX_DIV)
#error AC1210_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC5)
#if (UC_CGM_AC1210_DC5_DIV > UC_CGM_AC1210_DC5_MAX_DIV)
#error AC1210_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC121 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC121_DC0)
#if (UC_CGM_AC121_DC0_DIV > UC_CGM_AC121_DC0_MAX_DIV)
#error AC121_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC1)
#if (UC_CGM_AC121_DC1_DIV > UC_CGM_AC121_DC1_MAX_DIV)
#error AC121_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC2)
#if (UC_CGM_AC121_DC2_DIV > UC_CGM_AC121_DC2_MAX_DIV)
#error AC121_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC3)
#if (UC_CGM_AC121_DC3_DIV > UC_CGM_AC121_DC3_MAX_DIV)
#error AC121_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC4)
#if (UC_CGM_AC121_DC4_DIV > UC_CGM_AC121_DC4_MAX_DIV)
#error AC121_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC5)
#if (UC_CGM_AC121_DC5_DIV > UC_CGM_AC121_DC5_MAX_DIV)
#error AC121_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC12 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12_DC0)
#if (UC_CGM_AC12_DC0_DIV > UC_CGM_AC12_DC0_MAX_DIV)
#error AC12_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC1)
#if (UC_CGM_AC12_DC1_DIV > UC_CGM_AC12_DC1_MAX_DIV)
#error AC12_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC2)
#if (UC_CGM_AC12_DC2_DIV > UC_CGM_AC12_DC2_MAX_DIV)
#error AC12_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC3)
#if (UC_CGM_AC12_DC3_DIV > UC_CGM_AC12_DC3_MAX_DIV)
#error AC12_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC4)
#if (UC_CGM_AC12_DC4_DIV > UC_CGM_AC12_DC4_MAX_DIV)
#error AC12_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC5)
#if (UC_CGM_AC12_DC5_DIV > UC_CGM_AC12_DC5_MAX_DIV)
#error AC12_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC1 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0 && UC_CGM_AC1_DC0_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC0_DIV) > UC_CGM_AC1_DC0_MAX_CLOCK)
#error AC1_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC1 && UC_CGM_AC1_DC1_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC1_DIV) > UC_CGM_AC1_DC1_MAX_CLOCK)
#error AC1_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC2 && UC_CGM_AC1_DC2_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC2_DIV) > UC_CGM_AC1_DC2_MAX_CLOCK)
#error AC1_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC3 && UC_CGM_AC1_DC3_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC3_DIV) > UC_CGM_AC1_DC3_MAX_CLOCK)
#error AC1_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC4 && UC_CGM_AC1_DC4_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC4_DIV) > UC_CGM_AC1_DC4_MAX_CLOCK)
#error AC1_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC5 && UC_CGM_AC1_DC5_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC5_DIV) > UC_CGM_AC1_DC5_MAX_CLOCK)
#error AC1_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC1 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0 && UC_CGM_AC1_DC0_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC0_DIV) > UC_CGM_AC1_DC0_MAX_CLOCK)
#error AC1_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC1 && UC_CGM_AC1_DC1_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC1_DIV) > UC_CGM_AC1_DC1_MAX_CLOCK)
#error AC1_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC2 && UC_CGM_AC1_DC2_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC2_DIV) > UC_CGM_AC1_DC2_MAX_CLOCK)
#error AC1_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC3 && UC_CGM_AC1_DC3_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC3_DIV) > UC_CGM_AC1_DC3_MAX_CLOCK)
#error AC1_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC4 && UC_CGM_AC1_DC4_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC4_DIV) > UC_CGM_AC1_DC4_MAX_CLOCK)
#error AC1_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC5 && UC_CGM_AC1_DC5_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC5_DIV) > UC_CGM_AC1_DC5_MAX_CLOCK)
#error AC1_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC2 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0 && UC_CGM_AC2_DC0_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC0_DIV) > UC_CGM_AC2_DC0_MAX_CLOCK)
#error AC2_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC1 && UC_CGM_AC2_DC1_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC1_DIV) > UC_CGM_AC2_DC1_MAX_CLOCK)
#error AC2_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC2 && UC_CGM_AC2_DC2_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC2_DIV) > UC_CGM_AC2_DC2_MAX_CLOCK)
#error AC2_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC3 && UC_CGM_AC2_DC3_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC3_DIV) > UC_CGM_AC2_DC3_MAX_CLOCK)
#error AC2_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC4 && UC_CGM_AC2_DC4_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC4_DIV) > UC_CGM_AC2_DC4_MAX_CLOCK)
#error AC2_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC5 && UC_CGM_AC2_DC5_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC5_DIV) > UC_CGM_AC2_DC5_MAX_CLOCK)
#error AC2_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC3 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3_DC0 && UC_CGM_AC3_DC0_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC0_DIV) > UC_CGM_AC3_DC0_MAX_CLOCK)
#error AC3_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC1 && UC_CGM_AC3_DC1_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC1_DIV) > UC_CGM_AC3_DC1_MAX_CLOCK)
#error AC3_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC2 && UC_CGM_AC3_DC2_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC2_DIV) > UC_CGM_AC3_DC2_MAX_CLOCK)
#error AC3_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC3 && UC_CGM_AC3_DC3_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC3_DIV) > UC_CGM_AC3_DC3_MAX_CLOCK)
#error AC3_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC4 && UC_CGM_AC3_DC4_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC4_DIV) > UC_CGM_AC3_DC4_MAX_CLOCK)
#error AC3_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC5 && UC_CGM_AC3_DC5_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC5_DIV) > UC_CGM_AC3_DC5_MAX_CLOCK)
#error AC3_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC4 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4_DC0 && UC_CGM_AC4_DC0_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC0_DIV) > UC_CGM_AC4_DC0_MAX_CLOCK)
#error AC4_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC1 && UC_CGM_AC4_DC1_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC1_DIV) > UC_CGM_AC4_DC1_MAX_CLOCK)
#error AC4_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC2 && UC_CGM_AC4_DC2_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC2_DIV) > UC_CGM_AC4_DC2_MAX_CLOCK)
#error AC4_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC3 && UC_CGM_AC4_DC3_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC3_DIV) > UC_CGM_AC4_DC3_MAX_CLOCK)
#error AC4_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC4 && UC_CGM_AC4_DC4_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC4_DIV) > UC_CGM_AC4_DC4_MAX_CLOCK)
#error AC4_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC5 && UC_CGM_AC4_DC5_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC5_DIV) > UC_CGM_AC4_DC5_MAX_CLOCK)
#error AC4_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC5 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0 && UC_CGM_AC5_DC0_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC0_DIV) > UC_CGM_AC5_DC0_MAX_CLOCK)
#error AC5_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC1 && UC_CGM_AC5_DC1_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC1_DIV) > UC_CGM_AC5_DC1_MAX_CLOCK)
#error AC5_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC2 && UC_CGM_AC5_DC2_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC2_DIV) > UC_CGM_AC5_DC2_MAX_CLOCK)
#error AC5_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC3 && UC_CGM_AC5_DC3_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC3_DIV) > UC_CGM_AC5_DC3_MAX_CLOCK)
#error AC5_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC4 && UC_CGM_AC5_DC4_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC4_DIV) > UC_CGM_AC5_DC4_MAX_CLOCK)
#error AC5_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC5 && UC_CGM_AC5_DC5_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC5_DIV) > UC_CGM_AC5_DC5_MAX_CLOCK)
#error AC5_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC6 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6_DC0 && UC_CGM_AC6_DC0_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC0_DIV) > UC_CGM_AC6_DC0_MAX_CLOCK)
#error AC6_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC1 && UC_CGM_AC6_DC1_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC1_DIV) > UC_CGM_AC6_DC1_MAX_CLOCK)
#error AC6_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC2 && UC_CGM_AC6_DC2_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC2_DIV) > UC_CGM_AC6_DC2_MAX_CLOCK)
#error AC6_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC3 && UC_CGM_AC6_DC3_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC3_DIV) > UC_CGM_AC6_DC3_MAX_CLOCK)
#error AC6_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC4 && UC_CGM_AC6_DC4_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC4_DIV) > UC_CGM_AC6_DC4_MAX_CLOCK)
#error AC6_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC5 && UC_CGM_AC6_DC5_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC5_DIV) > UC_CGM_AC6_DC5_MAX_CLOCK)
#error AC6_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC7 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7_DC0 && UC_CGM_AC7_DC0_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC0_DIV) > UC_CGM_AC7_DC0_MAX_CLOCK)
#error AC7_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC1 && UC_CGM_AC7_DC1_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC1_DIV) > UC_CGM_AC7_DC1_MAX_CLOCK)
#error AC7_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC2 && UC_CGM_AC7_DC2_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC2_DIV) > UC_CGM_AC7_DC2_MAX_CLOCK)
#error AC7_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC3 && UC_CGM_AC7_DC3_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC3_DIV) > UC_CGM_AC7_DC3_MAX_CLOCK)
#error AC7_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC4 && UC_CGM_AC7_DC4_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC4_DIV) > UC_CGM_AC7_DC4_MAX_CLOCK)
#error AC7_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC5 && UC_CGM_AC7_DC5_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC5_DIV) > UC_CGM_AC7_DC5_MAX_CLOCK)
#error AC7_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC8 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8_DC0 && UC_CGM_AC8_DC0_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC0_DIV) > UC_CGM_AC8_DC0_MAX_CLOCK)
#error AC8_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC1 && UC_CGM_AC8_DC1_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC1_DIV) > UC_CGM_AC8_DC1_MAX_CLOCK)
#error AC8_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC2 && UC_CGM_AC8_DC2_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC2_DIV) > UC_CGM_AC8_DC2_MAX_CLOCK)
#error AC8_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC3 && UC_CGM_AC8_DC3_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC3_DIV) > UC_CGM_AC8_DC3_MAX_CLOCK)
#error AC8_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC4 && UC_CGM_AC8_DC4_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC4_DIV) > UC_CGM_AC8_DC4_MAX_CLOCK)
#error AC8_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC5 && UC_CGM_AC8_DC5_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC5_DIV) > UC_CGM_AC8_DC5_MAX_CLOCK)
#error AC8_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC9 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9_DC0 && UC_CGM_AC9_DC0_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC0_DIV) > UC_CGM_AC9_DC0_MAX_CLOCK)
#error AC9_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC1 && UC_CGM_AC9_DC1_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC1_DIV) > UC_CGM_AC9_DC1_MAX_CLOCK)
#error AC9_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC2 && UC_CGM_AC9_DC2_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC2_DIV) > UC_CGM_AC9_DC2_MAX_CLOCK)
#error AC9_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC3 && UC_CGM_AC9_DC3_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC3_DIV) > UC_CGM_AC9_DC3_MAX_CLOCK)
#error AC9_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC4 && UC_CGM_AC9_DC4_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC4_DIV) > UC_CGM_AC9_DC4_MAX_CLOCK)
#error AC9_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC5 && UC_CGM_AC9_DC5_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC5_DIV) > UC_CGM_AC9_DC5_MAX_CLOCK)
#error AC9_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC10 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10_DC0 && UC_CGM_AC10_DC0_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC0_DIV) > UC_CGM_AC10_DC0_MAX_CLOCK)
#error AC10_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC1 && UC_CGM_AC10_DC1_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC1_DIV) > UC_CGM_AC10_DC1_MAX_CLOCK)
#error AC10_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC2 && UC_CGM_AC10_DC2_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC2_DIV) > UC_CGM_AC10_DC2_MAX_CLOCK)
#error AC10_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC3 && UC_CGM_AC10_DC3_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC3_DIV) > UC_CGM_AC10_DC3_MAX_CLOCK)
#error AC10_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC4 && UC_CGM_AC10_DC4_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC4_DIV) > UC_CGM_AC10_DC4_MAX_CLOCK)
#error AC10_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC5 && UC_CGM_AC10_DC5_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC5_DIV) > UC_CGM_AC10_DC5_MAX_CLOCK)
#error AC10_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC11 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC11_DC0 && UC_CGM_AC11_DC0_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC0_DIV) > UC_CGM_AC11_DC0_MAX_CLOCK)
#error AC11_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC1 && UC_CGM_AC11_DC1_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC1_DIV) > UC_CGM_AC11_DC1_MAX_CLOCK)
#error AC11_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC2 && UC_CGM_AC11_DC2_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC2_DIV) > UC_CGM_AC11_DC2_MAX_CLOCK)
#error AC11_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC3 && UC_CGM_AC11_DC3_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC3_DIV) > UC_CGM_AC11_DC3_MAX_CLOCK)
#error AC11_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC4 && UC_CGM_AC11_DC4_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC4_DIV) > UC_CGM_AC11_DC4_MAX_CLOCK)
#error AC11_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC5 && UC_CGM_AC11_DC5_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC5_DIV) > UC_CGM_AC11_DC5_MAX_CLOCK)
#error AC11_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC12 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12_DC0 && UC_CGM_AC12_DC0_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC0_DIV) > UC_CGM_AC12_DC0_MAX_CLOCK)
#error AC12_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC1 && UC_CGM_AC12_DC1_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC1_DIV) > UC_CGM_AC12_DC1_MAX_CLOCK)
#error AC12_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC2 && UC_CGM_AC12_DC2_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC2_DIV) > UC_CGM_AC12_DC2_MAX_CLOCK)
#error AC12_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC3 && UC_CGM_AC12_DC3_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC3_DIV) > UC_CGM_AC12_DC3_MAX_CLOCK)
#error AC12_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC4 && UC_CGM_AC12_DC4_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC4_DIV) > UC_CGM_AC12_DC4_MAX_CLOCK)
#error AC12_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC5 && UC_CGM_AC12_DC5_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC5_DIV) > UC_CGM_AC12_DC5_MAX_CLOCK)
#error AC12_DC5 Clock is > MAX value
#endif
#endif


#endif /* BSP_HW_INIT_CHECK */
#endif /* UC_SPC572l64_SPEC_H_ */
